==> mhu-lib-core-3.3.6-sources.jar: de/mhus/lib/core/strategy/DefaultMonitor.java <==
/**
 * Copyright 2018 Mike Hummel
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.mhus.lib.core.strategy;

import de.mhus.lib.core.logging.Log;

public class DefaultMonitor implements Monitor {

	private long steps;
	private long step;
	private StringBuilder lineBuffer = new StringBuilder();
	private Log log = null;

	public DefaultMonitor(Class<?> owner) {
		log = Log.getLog(owner);
	}
	
	public long getSteps() {
		return steps;
	}

	@Override
	public void setSteps(long steps) {
		this.steps = steps;
	}

	public long getStep() {
		return step;
	}

	@Override
	public void setStep(long step) {
		this.step = step;
	}

	@Override
	public Log log() {
		return log;
	}

	@Override
	public void println() {
		synchronized (lineBuffer) {
			log().i("STDOUT", lineBuffer);
			lineBuffer = new StringBuilder();
		}
	}

	@Override
	public void println(Object... out) {
		print(out);
		println();
	}

	@Override
	public void print(Object... out) {
		synchronized (lineBuffer) {
			for (Object o : out)
				lineBuffer.append(o);
		}
	}

	@Override
	public void incrementStep() {
		step++;
	}

}

==> mhu-lib-core-3.6.1-sources.jar: de/mhus/lib/core/strategy/DefaultMonitor.java <==
/**
 * Copyright 2018 Mike Hummel
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.mhus.lib.core.strategy;

import de.mhus.lib.core.logging.Log;

public class DefaultMonitor implements Monitor {

	private long steps;
	private long step;
	private StringBuilder lineBuffer = new StringBuilder();
	private Log log = null;

	public DefaultMonitor(Class<?> owner) {
		log = Log.getLog(owner);
	}
	
	public long getSteps() {
		return steps;
	}

	@Override
	public void setSteps(long steps) {
		this.steps = steps;
	}

	public long getStep() {
		return step;
	}

	@Override
	public void setStep(long step) {
		this.step = step;
	}

	@Override
	public Log log() {
		return log;
	}

	@Override
	public void println() {
		synchronized (lineBuffer) {
			log().i("STDOUT", lineBuffer);
			lineBuffer = new StringBuilder();
		}
	}

	@Override
	public void println(Object... out) {
		print(out);
		println();
	}

	@Override
	public void print(Object... out) {
		synchronized (lineBuffer) {
			for (Object o : out) {
				if (o instanceof Throwable)
					log.i(o);
				else
					lineBuffer.append(o);
			}
		}
	}

	@Override
	public void incrementStep() {
		step++;
	}

}
